/*
*  Rubrica
*  file: import.c
*  
*  Copyright (C) 2000-2001 Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#include <gnome.h>

#include "rubrica.h"
#include "file.h"
#include "file_old.h"
#include "main.h"
#include "dialog.h"
#include "import.h"
#include "import_int.h"
#include "import_vcard.h"
#include "view.h"
#include "card.h"

static gchar *gnomecard = "/.gnome/GnomeCard.gcrd";
static gchar *kdecard   = "/.kde/share/apps/kabc/std.vcf";

RubricaImportType importfrom;


void rubrica_import_init(GtkWidget *fentry, RubricaImportType import)
{  
  importfrom = import; /* import default will be csv file 
      
  if(import == IMPORT_VCARD)
    gtk_widget_set_sensitive(GTK_WIDGET(fentry), FALSE);
*/
}

void rubrica_import_set(RubricaImportType import)
{
  importfrom = (RubricaImportType) import;
}

RubricaImportType rubrica_import_get(void)
{
  return (RubricaImportType) importfrom;
}


gboolean rubrica_import_data(GtkWidget *app)
{
  Rubrica *rubrica;
  GtkWidget *fentry;
  gchar *filename = NULL;
  gchar *buffer, *titolo = NULL;
  
  fentry  = gnome_file_entry_gtk_entry(GNOME_FILE_ENTRY(rubrica_import_get_file_entry()));
  filename = g_strdup(gtk_entry_get_text(GTK_ENTRY(fentry)));
 
  switch (importfrom)
    {
    case IMPORT_GNOMECARD:
      /* 	 if no name is set in gnome_entry, then 
		 load default gnomecard addressbook 
      */
      if (strcmp(filename, "") == 0)
	{
	  /* load the default GnomeCard file: GnoneCard.gcrd*/
	  buffer = g_strdup(g_get_home_dir());	  
	  filename = g_strdup_printf("%s%s", buffer, gnomecard);

	  if (!g_file_exists(filename))
	    {
	      rubrica_dialog_error_loading_file(filename, RE_FILE_NOT_EXIST);

	      g_free(buffer);
	      g_free(filename);
	      return FALSE;
	    }

	  g_print("\nimporting gnomecard file: %s", filename);
	  rubrica_import_open_file(filename);
	  titolo = g_strdup(_("Imported_from_GnomeCard"));

	  g_free(buffer);
	  g_free(filename);	  
	}
      else	
	/* import a gnomecard file */
	{
	  gboolean ret;

	  g_print("\nimporting gnomecard file: %s", filename);
	  ret = rubrica_import_open_file(filename);

	  g_free(filename);
	  return ret;
	}
      break;
      
    case IMPORT_KAB:
      /* kab (kab 2.x) has a default database */
      buffer =  g_strdup(g_get_home_dir());      
      filename = g_strdup_printf("%s%s",buffer, kdecard);

      if (!g_file_exists(filename))
	{
	  rubrica_dialog_error_loading_file(filename, RE_FILE_NOT_EXIST);

	  g_free(buffer);
	  g_free(filename); 
	  return FALSE;
	}
      
      g_print("\nimporting Kabc file: %s", filename);      
      rubrica_import_open_file(filename);

      g_free(buffer);
      g_free(filename);      
      titolo = g_strdup(_("Imported_from_ Kabc"));
      break;

    case IMPORT_RUBRICA:
      if (strcmp(filename, "") == 0)
	{
	  rubrica_dialog_error_loading_file(NULL, RE_SELECT_FILE);
	  
	  return FALSE;
	}
      else
	/* apri il file e leggilo */
	{
	  g_print("\nimporting rubrica's file: %s", filename);
	  rubrica_import_open_old_rubrica_file(filename);

	  g_free(filename);
	}
      break;

    case IMPORT_CSV:
      if (strcmp(filename,"") == 0)
	{
	  rubrica_dialog_error_loading_file(NULL, RE_SELECT_FILE);

	  return FALSE;
	}
      else 
	{
	  g_print("\nimporting csv file: %s", filename);

	  rubrica_import_open_file(filename);      
	  titolo = g_strdup(_("Imported_from_csv"));	  

	  g_free(filename);
	}
      break;      

    case IMPORT_VCARD:
      if (strcmp(filename,"") == 0)
	{
	  rubrica_dialog_error_loading_file(NULL, RE_SELECT_FILE);

	  return FALSE;
	}
      else 
	{
	  g_print("\nimporting vcard file: %s", filename);

	  rubrica_import_open_file(filename);     
	  titolo = g_strdup(_("Imported_from_vcard"));	  

	  g_free(filename);
	}
      break;      
      
    default:
      return FALSE;
      break;

    }
  
  rubrica = rubrica_get_current_rubrica();

  rubrica_set_path(rubrica, g_dirname(filename));
  rubrica_set_name(rubrica, g_basename(filename));
  rubrica_set_new(rubrica, FALSE);
  rubrica_set_empty(rubrica, FALSE);
  rubrica_set_modified(rubrica, TRUE);

  rubrica_card_set_tab_name(titolo);
  rubrica_view_set_items(rubrica_get_items(rubrica));
  if (titolo)
    g_free(titolo);

  return TRUE;
}


gboolean rubrica_import_open_file(gchar *file)
{
  Rubrica *rubrica;
  FILE *fp;

  if ((fp=fopen(file, "r")) == NULL)
    {
      rubrica_dialog_error_loading_file (file, RE_IMPORT_FILE);

      return FALSE;
    }

  rubrica_card_add_page_view(NULL);
  rubrica = rubrica_get_current_rubrica();

  while (!feof(fp))
    {
      gchar buffer[124];

      while (fgets(buffer, 124, fp))
	{	  
	  rubrica_import_vcard_decode_buffer(rubrica, buffer);
	}
    }

  return TRUE;
}

void rubrica_export_data(void)
{
}


gint rubrica_import_open_old_rubrica_file(gchar *fname)
{
  RubricaErrorType err;
  gboolean loaded;
  
  loaded = rubrica_file_load_xmlfile(fname, &err);

  if (!loaded)
    {
      rubrica_dialog_error_loading_file(fname, err);      

      return 0;
    }
  
  return (gint) rubrica_view_get_indirizzi();    
}



