/*
*  Rubrica
*  file: import_int.c
*
*  
*  Copyright (C) 2000-2001 Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <string.h>

#include <gnome.h>

#include "import_cb.h"
#include "import_int.h"
#include "import.h"
#include "rubrica_ui.h"

GtkWidget *fileentry;

GSList    *import_group = NULL;
GtkWidget *radio_gnome;
GtkWidget *radio_kde;
GtkWidget *radio_csv;
GtkWidget *radio_rubrica;
GtkWidget *radio_vcard;


GtkWidget*
create_import_dialog (GtkWidget *parent)
{
  GtkWidget *import_dialog;
  GtkWidget *dialog_vbox;
  GtkWidget *frame;
  GtkWidget *vbox;
  GtkWidget *label;
  GtkWidget *table;

  GtkWidget *frame2;
  gchar *buffer;


  buffer = g_strdup(g_get_home_dir());

  import_dialog = gtk_dialog_new();
  gtk_dialog_add_buttons(GTK_DIALOG(import_dialog), 			 
			 GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE, 
			 GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,NULL);
  gtk_window_set_title(GTK_WINDOW(import_dialog), _("Import file"));
  gtk_window_set_resizable (GTK_WINDOW (import_dialog), FALSE);
  
  gtk_dialog_set_has_separator (GTK_DIALOG(import_dialog), TRUE);
  gtk_window_set_position (GTK_WINDOW (import_dialog), GTK_WIN_POS_CENTER);
  gtk_window_set_policy (GTK_WINDOW (import_dialog), FALSE, FALSE, FALSE);

  dialog_vbox = GTK_DIALOG (import_dialog)->vbox;
  gtk_widget_show (dialog_vbox);

  frame = rubrica_ui_frame_new (_("Import"));
  gtk_box_pack_start (GTK_BOX (dialog_vbox), frame, TRUE, TRUE, 2);
  gtk_container_set_border_width (GTK_CONTAINER (frame), 5);

  vbox = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox);
  gtk_container_add (GTK_CONTAINER (frame), vbox);

  label = gtk_label_new (_("Import addressbook from:"));
  gtk_widget_show (label);
  gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 3);
  gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
  gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);

  /*      Table
   */
  table = gtk_table_new (5, 2, TRUE);
  gtk_widget_show (table);
  gtk_box_pack_start (GTK_BOX (vbox), table, TRUE, TRUE, 5);
  gtk_container_set_border_width (GTK_CONTAINER (table), 5);
  gtk_table_set_row_spacings (GTK_TABLE (table), 3);
  gtk_table_set_col_spacings (GTK_TABLE (table), 5);

  /*    radio buttons
  */
  radio_gnome = rubrica_ui_tabled_radio_new(table, import_group, "GnomeCard", 0, 1, 0, 1);
  import_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radio_gnome));
  
  radio_kde = rubrica_ui_tabled_radio_new(table, import_group, _("Kde addressbook"), 0, 1, 1, 2);
  import_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radio_kde));

  radio_csv = rubrica_ui_tabled_radio_new(table, import_group, _("csv file"), 0, 1, 2, 3);
  import_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radio_csv));

  radio_rubrica = rubrica_ui_tabled_radio_new(table, import_group, _("Rubrica old version"), 0, 1, 3, 4);
  import_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radio_csv));
  
  radio_vcard = rubrica_ui_tabled_radio_new(table, import_group, _("VCard file"), 0, 1, 4, 5);
  
  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio_gnome), TRUE); 

  frame2 = rubrica_ui_frame_new (_("Import file"));
  gtk_box_pack_start (GTK_BOX (vbox), frame2, TRUE, TRUE, 5);
  gtk_container_set_border_width (GTK_CONTAINER (frame2), 5);

  fileentry = gnome_file_entry_new (NULL, _("Import file"));
  gtk_widget_show (fileentry);
  gtk_container_add (GTK_CONTAINER (frame2), fileentry);
  gtk_container_set_border_width (GTK_CONTAINER (fileentry), 5);
  gnome_file_entry_set_directory_entry (GNOME_FILE_ENTRY (fileentry), FALSE);
  gnome_file_entry_set_default_path(GNOME_FILE_ENTRY (fileentry), buffer);
  gnome_file_entry_set_modal (GNOME_FILE_ENTRY (fileentry), TRUE);


  /*    Funzioni di Callback
  */
  gtk_signal_connect (GTK_OBJECT (radio_gnome), "toggled",
                      GTK_SIGNAL_FUNC (on_radio_gnome_toggled),
                      fileentry);
  gtk_signal_connect (GTK_OBJECT (radio_kde), "toggled",
                      GTK_SIGNAL_FUNC (on_radio_kde_toggled),
                      fileentry);
  gtk_signal_connect (GTK_OBJECT (radio_rubrica), "toggled",
                      GTK_SIGNAL_FUNC (on_radio_rubrica_toggled),
		      fileentry);
  gtk_signal_connect (GTK_OBJECT (radio_csv), "toggled",
                      GTK_SIGNAL_FUNC (on_radio_csv_toggled),
                      fileentry);
  gtk_signal_connect (GTK_OBJECT (radio_vcard), "toggled",
                      GTK_SIGNAL_FUNC (on_radio_vcard_toggled),
                      fileentry);
  
  rubrica_import_init(fileentry, IMPORT_GNOMECARD);

  return import_dialog;
}

GtkWidget *rubrica_import_get_file_entry(void)
{
  return (GtkWidget*) fileentry;
}
