/*
*  Rubrica
*  file: import_vcard.h
*  
*  Copyright (C) 2000-2001 Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#ifndef _IMPORT_VCARD_H
#define _IMPORT_VCARD_H

#include "rubrica.h"
#include "rubrica_type.h"

typedef enum {
  BEGIN = 0,
  FN, N, REV, BDAY,
  ADR, TEL, EMAIL, URL, TZ, GEO,
  TITLE, ORG, CATEGORIES, NOTE,
  KEY, END,
  BAD  // this isn't a VCard token
} RubricaVCardTokenType;


typedef enum {
  VCARD = 0,
  HOME,  WORK, POSTAL, PARCEL, DOM, INTL, PREF,
  VOICE, FAX, MSG, CELL, PAGER, BBS, MODEM, CAR, ISDN, VIDEO,  
  AOL, INTERNET, APPLELINK, ATTMAIL, CIS, EWORLD, IBMMail, MCIMAIL, 
  POWERSHARE, PRODIGY, TLX, X400, PGP, X509, TYPE,
  QUOTED_PRINTABLE,
  NO_SUB,  SUB_BAD, SUB_END  // these aren't vcard tokens
} RubricaVCardSubTokenType;


typedef enum {
  KDE_EXT_Profession,
  KDE_EXT_Department,
  KDE_EXT_ManagersName,
  KDE_EXT_AssistantsName,
  KDE_EXT_Office,
  KDE_EXT_SpousesName,
  KDE_EXT_Anniversary,
  KDE_EXT_CUSTOM,
  KDE_EXT_END                   // this isn't a kde estra token
} RubricaExtraVCardTokenType;   // kde vcard extensions


typedef struct _RubricaVCardToken {
  gchar *str;
  RubricaVCardTokenType tok;
  gboolean subtok;
  gboolean kdeextra;
} RubricaVCardToken;

typedef struct _RubricaVCardSubToken {
  gchar *str;
  RubricaVCardSubTokenType stok;
} RubricaVCardSubToken;


typedef struct _RubricaExtraVCardToken {
  gchar *str;
  RubricaExtraVCardTokenType token;
} RubricaExtraVCardToken;


RubricaVCardTokenType rubrica_import_vcard_get_token(gchar *tkbuf);
gchar *rubrica_import_vcard_get_string(gchar *buf);

RubricaVCardTokenType rubrica_import_vcard_decode_token(gchar *str, RubricaVCardSubTokenType *st);
RubricaVCardSubTokenType rubrica_import_vcard_decode_subtoken(gchar *str);

void rubrica_import_vcard_decode_string(char *buf, gchar *dec[7]);
void rubrica_import_vcard_decode_buffer(Rubrica *rubrica, gchar *buf);
gchar *rubrica_import_vcard_decode_note(GList *l, gchar *s);


gchar *rubrica_import_vcard_merge_note(GList *l1, GList *l2, gint len1, gint len2);
void rubrica_import_vcard_split_buffer(gchar *buf, gchar **s, gchar **dt, 
				       gboolean *fl);

void rubrica_import_vcard_free_note(GList *n);
void rubrica_import_vcard_clean_buffer(gchar *buffer, gboolean *fl);

time_t rubrica_import_vcard_decode_date(gchar *date, gboolean has_hour);

#endif
